
from django.db.models import Q
from django.conf import settings
from django.core.urlresolvers import resolve, Resolver404
from django.contrib.sites.models import Site

from seo.models import PageMeta


def _get_url_full_name(request):

    name = ''

    try:
        url = resolve(request.path_info)
    except Resolver404:
        return ''

    if url.url_name is None:
        return ''

    if url.namespaces:
        name = ':'.join(url.namespaces) + ':'

    name += url.url_name

    return name


def _get_current_url(request):
    return request.path.replace('/%s' % request.LANGUAGE_CODE, '', 1)


def get_page_meta(request, context):

    host = request.META.get('HTTP_HOST')

    try:
        site_id = Site.objects.get(domain=host)
    except Site.DoesNotExist:
        site_id = settings.SITE_ID

    try:
        page_meta = PageMeta.objects.get(
            Q(site_id=site_id) & (
                Q(url=_get_current_url(request)) |
                Q(url=_get_url_full_name(request))
            )
        )

        page_meta.compile(context)

        return page_meta

    except PageMeta.DoesNotExist:
        return None



# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2017-11-03 11:24
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
        ('seo', '0002_model_translation'),
    ]

    operations = [
        migrations.AddField(
            model_name='pagemeta',
            name='site',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, to='sites.Site', verbose_name='Site'),
        ),
        migrations.AlterField(
            model_name='pagemeta',
            name='url',
            field=models.CharField(db_index=True, max_length=255, verbose_name='URL'),
        ),
        migrations.AlterUniqueTogether(
            name='pagemeta',
            unique_together=set([('site', 'url')]),
        ),
    ]




import seo.translation

from django.contrib import admin

from modeltranslation.admin import TranslationAdmin

from seo.models import PageMeta


class PageMetaAdmin(TranslationAdmin):
    list_display = ['url', 'title', 'robots', 'site']
    list_filter = ['site']
    list_editable = ['robots']


admin.site.register(PageMeta, PageMetaAdmin)
